@@ -4,20 +4,21 @@ print(startup:::is_installed())
 
 path <- tempdir()
 
-res <- startup:::is_installed(path = path)
+file <- file.path(path, ".Rprofile")
+res <- startup:::is_installed(file)
 print(res)
-stopifnot(!isTRUE(res))
+stopifnot(!res)
 
 print(startup:::install(path = path))
 
-res <- startup:::is_installed(path = path)
+res <- startup:::is_installed(file)
 print(res)
-stopifnot(isTRUE(res))
+stopifnot(res)
 
 print(startup:::uninstall(path = path))
 
-res <- startup:::is_installed(path = path)
+res <- startup:::is_installed(file)
 print(res)
-stopifnot(!isTRUE(res))
+stopifnot(!res)
 
 message("*** install() / uninstall() ... DONE")
